summaryrefslogtreecommitdiffstats
path: root/ash/test/ash_test_base.h
diff options
context:
space:
mode:
authorbartfab@chromium.org <bartfab@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-11-21 13:58:27 +0000
committerbartfab@chromium.org <bartfab@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-11-21 13:58:27 +0000
commit91545875f50bd58f48d1311355c8f0e4eef847e6 (patch)
treedcca143751c99c5434f72f3fc26fe7371dc3b257 /ash/test/ash_test_base.h
parent125d7dcd64991fa580bcd9cb98e43e9baa28f670 (diff)
downloadchromium_src-91545875f50bd58f48d1311355c8f0e4eef847e6.zip
chromium_src-91545875f50bd58f48d1311355c8f0e4eef847e6.tar.gz
chromium_src-91545875f50bd58f48d1311355c8f0e4eef847e6.tar.bz2
Let chromeos::User decide whether the current session can be locked
We have several different methods that try to determine whether the current session can be locked. This redundancy is difficult to maintain and has drifted out of sync in the past. The CL consolidates all checks and makes the chromeos::User class the autoritative source for whether the current session can be locked or not. BUG=152928 Review URL: https://chromiumcodereview.appspot.com/11412100 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@169031 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/test/ash_test_base.h')
-rw-r--r--ash/test/ash_test_base.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/ash/test/ash_test_base.h b/ash/test/ash_test_base.h
index e21225a..0865f39 100644
--- a/ash/test/ash_test_base.h
+++ b/ash/test/ash_test_base.h
@@ -52,10 +52,11 @@ class AshTestBase : public testing::Test {
protected:
void RunAllPendingInMessageLoop();
// Utility methods to emulate user logged in or not and
// session started or not cases.
void SetSessionStarted(bool session_started);
void SetUserLoggedIn(bool user_logged_in);
+ void SetCanLockScreen(bool can_lock_screen);
private:
MessageLoopForUI message_loop_;
@@ -52,10 +52,11 @@ class AshTestBase : public testing::Test {
protected:
void RunAllPendingInMessageLoop();
- // Utility methods to emulate user logged in or not and
- // session started or not cases.
+ // Utility methods to emulate user logged in or not, session started or not
+ // and user able to lock screen or not cases.
void SetSessionStarted(bool session_started);
void SetUserLoggedIn(bool user_logged_in);